import { useEffect, useState } from "react";
import Button from "../atoms/Button";
import Input from "../atoms/Input";
import Select from "../atoms/Select";
import Search from "./Search";

const FilterSearch = ({ orders, setOrdersToShow }) => {
  const [all, setAll] = useState(false);
  const [received, setReceived] = useState(false);
  const [fulfilled, setFulfilled] = useState(false);
  const [cancelled, setCancelled] = useState(false);


  const RECEIVED = "RECEIVED";
  const FULFILLED = "FULFILLED";
  const CANCELLED = "CANCELLED";

  const reset = () => {
    setAll(true);
    setReceived(false);
    setFulfilled(false);
    setCancelled(false);
  };
  const receive = () => {
    setAll(false);
    setReceived(!received);
    if (received && !fulfilled && !cancelled) {
      setAll(true);
    }
  };
  const fulfill = () => {
    setAll(false);
    setFulfilled(!fulfilled);
    if (!received && fulfilled && !cancelled) {
      setAll(true);
    }
  };
  const cancel = () => {
    setAll(false);
    setCancelled(!cancelled);
    if (!received && !fulfilled && cancelled) {
      setAll(true);
    }
  };



  useEffect(() => {
    if (all) {
      setOrdersToShow(orders);
    } else {
      const newOrders = { allIds: [], byId: {} };
      orders.allIds.forEach((wareId) => {
        const order = orders.byId[wareId];
        switch (order.status) {
          case RECEIVED:
            if (all || received) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          case FULFILLED:
            if (all || fulfilled) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          case CANCELLED:
            if (all || cancelled) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          default:
            break;
        }
      });
  
      setOrdersToShow(newOrders);
    }
  }, [orders, setOrdersToShow, all, received, fulfilled, cancelled]);

  if (!orders.allIds.length) return null;

  return (
    <div className="filter-search">
      <div className="filter">
        <div className="text">Filter:</div>

        <div className="filter-btns">
          <Button
            className={`filter-all ${all ? "selected" : ""}`}
            onClick={reset}
            text="All"
          />
          <Button
            className={`filter-rec ${received ? "selected" : ""}`}
            onClick={receive}
            text="Received"
          />
          <Button
            className={`filter-ful ${fulfilled ? "selected" : ""}`}
            onClick={fulfill}
            text="Fulfilled"
          />
          <Button
            className={`filter-can ${cancelled ? "selected" : ""}`}
            onClick={cancel}
            text="Cancelled"
          />
        </div>
      </div>

      <Search setOrdersToShow={setOrdersToShow} />
    </div>
  );
};;

export default FilterSearch;
